@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '2.1.1';
+    return '2.1.3.3';
   }
 
   function GetHelp()
@@ -114,7 +114,7 @@ class MetaMax extends CMSModule
 
   function MinimumCMSVersion()
   {
-    return "1.10";
+    return "1.11";
   }
 
   function MaximumCMSVersion()
@@ -202,4 +202,4 @@ class MetaMax extends CMSModule
 
 
 } //end class
-?>
+?>
\ No newline at end of file
