@@ -3,7 +3,6 @@
 if (!isset($gCms)) exit;
 
 
-
 ///// GLOBALS /////
 
 $gCms = cmsms();
@@ -12,8 +11,9 @@ $db = $gCms->GetDb();
 $config = $gCms->GetConfig();
 $tmp = $this->GetPreference('detail_returnid',-1);
 $hm =& $gCms->GetHierarchyManager();
-$page_meta = $gCms->variables['content_obj'];
-$curnode =& $hm->getNodeByAlias($gCms->variables['page_name']);
+$page_meta = cms_utils::get_current_content();
+$curalias = cms_utils::get_current_alias();
+$curnode =& $hm->getNodeByAlias($curalias);
 $curcontent =& $curnode->GetContent();
 $modified_date = $curcontent->GetModifiedDate();
 $modified_date = date('Y-m-d\TH:i:sP',$modified_date);
@@ -81,6 +81,7 @@ if ($checkContent != '') {
     }
     $contentBasic = $curcontent->GetPropertyValue('content_en');
     $keywords = $contentBasic . $countVars;
+	$keywords = trim(preg_replace('/\t+/', '', $keywords));
     $keywords = preg_replace('/[\n\r]/','',$keywords);
     $keywords = preg_replace('/[\.\,]/','',$keywords);
     $keywords = str_replace('><','> <',$keywords);
@@ -180,37 +181,46 @@ if (is_array($worddiff)) {
 
 ///// DESCRIPTION /////
 
-if ($curcontent->GetPropertyValue($description_block) != '') {
-    $desc = $curcontent->GetPropertyValue($description_block);
-    $desc = preg_replace('/[\n\r]/',' ',$desc);
-    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
-    $desc = str_replace('><','> <',$desc);
-    $desc = strip_tags(str_replace('"','',$desc));
-    $desc = preg_replace('/{.*}/','',$desc);
-    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-} elseif ($this->GetPreference('auto_title','1') == 1 && $curcontent->GetPropertyValue($description_block) == '') {
-    if ($contentVar != '') {
-        foreach ($contentVar as $key => $countVar2) {
-			$content_value = $smarty->get_template_vars($countVar2);
-			if($content_value != "") {
-				$countVars2[] = $content_value;
+if ($this->GetPreference('block_title','') != '') {
+	if ($smarty->get_template_vars($description_block) != '') {
+	    $desc = $smarty->get_template_vars($description_block);
+	    $desc = preg_replace('/[\n\r]/',' ',$desc);
+	    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
+	    $desc = str_replace('><','> <',$desc);
+	    $desc = strip_tags(str_replace('"','',$desc));
+	    $desc = preg_replace('/{.*}/','',$desc);
+	    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
+	} elseif ($curcontent->GetPropertyValue($description_block) != '') {
+	    $desc = $curcontent->GetPropertyValue($description_block);
+	    $desc = preg_replace('/[\n\r]/',' ',$desc);
+	    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
+	    $desc = str_replace('><','> <',$desc);
+	    $desc = strip_tags(str_replace('"','',$desc));
+	    $desc = preg_replace('/{.*}/','',$desc);
+	    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
+	} else {
+		if ($contentVar != '') {
+			foreach ($contentVar as $key => $countVar2) {
+				$content_value = $smarty->get_template_vars($countVar2);
+				if($content_value != "") {
+					$countVars2[] = $content_value;
+				}
+				$content_value = NULL;
 			}
-			$content_value = NULL;
-        }
-        $countVars2 = preg_replace('!\s+!', ' ', trim(strip_tags(join(' ', $countVars2))));
-    }
-    $contentBasic = $curcontent->GetPropertyValue('content_en');
-    $desc = $countVars2 . ' ' . $contentBasic;
-    $desc = preg_replace('/[\n\r]/',' ',$desc);
-    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
-    $desc = trim($desc);
-    $desc = str_replace('><','> <',$desc);
-    $desc = strip_tags(str_replace('"','',$desc));
-    $desc = preg_replace('/{.*}/','',$desc);
-    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-    $desclength = $this->GetPreference('length_title','30');
-    $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
-} elseif ($this->GetPreference('auto_title','1') == 1) {
+			$countVars2 = preg_replace('!\s+!', ' ', trim(strip_tags(join(' ', $countVars2))));
+		}
+		$contentBasic = $curcontent->GetPropertyValue('content_en');
+		$desc = $countVars2 . ' ' . $contentBasic;
+		$desc = preg_replace('/[\n\r]/',' ',$desc);
+		$desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
+		$desc = str_replace('><','> <',$desc);
+		$desc = strip_tags(str_replace('"','',$desc));
+		$desc = preg_replace('/{.*}/','',$desc);
+		$desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
+		$desclength = $this->GetPreference('length_title','30');
+		$desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
+	}
+} elseif ($this->GetPreference('auto_title','1') == '1') {
     if ($contentVar != '') {
         foreach ($contentVar as $key => $countVar2) {
 			$content_value = $smarty->get_template_vars($countVar2);
@@ -232,7 +242,7 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } else {
-    $desc = '';
+	$desc = '';
 }
 
 
