@@ -44,7 +44,7 @@ $lang['meta_block_title'] = 'Name of metadata content block';
 $lang['meta_block_title_help'] = 'This should be the name given to your metadata content block, check module help for more info';
 $lang['content_var_title'] = 'Content block variables';
 $lang['content_var_title_help'] = 'A comma seperated list of variables';
-$lang['block_title'] = 'Name of page description content block';
+$lang['block_title'] = 'Name of page description content block or variable';
 $lang['canonical_block_title'] = 'Name of canonical content block';
 $lang['block_title_help'] = 'This should be the name given to your page description content block, check module help for more info';
 $lang['canonical_block_title_help'] = 'This should be the name given to your canonical link content block, check module help for more info';
@@ -265,6 +265,11 @@ $lang['changelog'] = '<ul>
 <li>Version 2.0 12 August 2014. Added the ability to specify keywords content block to append keywords per page. Minor bug fixes.</li>
 <li>Version 2.1 21 August 2014. Minor bug fix.</li>
 <li>Version 2.1.1 26 August 2014. Minor HTML5 bug fix.</li>
+<li>Version 2.1.2 14 October 2014. Minor bug fix.</li>
+<li>Version 2.1.3 27 October 2014. Compatability with CMSMS v2. Minor updates and bug fixes. Added the ability to get description from smarty varaible.</li>
+<li>Version 2.1.3.1 27 October 2014. Minor compatability fix.</li>
+<li>Version 2.1.3.2 29 October 2014. Minor bug fix.</li>
+<li>Version 2.1.3.3 2 December 2014. Minor bug fix where auto description may not have worked in certain circumstances.</li>
 </ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
